@@ -341,9 +341,6 @@ void Model::linearization(Azimuth* a)
   // right hand site
 
   double az = std::atan2(local.e2, local.e1);
-  std::cout << "??? azimuth " << (a->obs()*GON_TO_RAD - az)*RAD_TO_GON
-            << "\t" << a->obs() << "\t" << az*RAD_TO_GON
-            << "\n";
   rhs(++rhs_ind) = a->obs()*GON_TO_RAD - az;
 }
 
