@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef GNU_gama_xml_expat_h___GNU_Gama_interface_for_Expat_XML_parser
-#define GNU_gama_xml_expat_h___GNU_Gama_interface_for_Expat_XML_parser
+#ifndef GNU_gama_xml_expat_h_GNU_Gama_interface_for_Expat_XML_parser
+#define GNU_gama_xml_expat_h_GNU_Gama_interface_for_Expat_XML_parser
 
 
 #ifdef  GNU_gama_expat_1_1
