@@ -1,5 +1,5 @@
 /* matvec_test_001.cpp
-   Copyright (C) 2000, 2012  Ales Cepek <cepek@gnu.org>
+   Copyright (C) 2000, 2012, 2019  Ales Cepek <cepek@gnu.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -44,17 +44,17 @@ InitMat(Mat& M, double ini[], Mat& I, double inv[], double& cond, double& maxe)
 {
   long double inv0 = 1.0L/ini[0];
   inv[0] = inv0;
-  for (int i=1; i<M.rows(); i++)
+  for (typename Mat::size_type i=1; i<M.rows(); i++)
     {
       long double s = 0;
-      for (int j=1; j<=i; j++)
+      for (typename Mat::size_type j=1; j<=i; j++)
         s -= ini[j]*inv[i-j];
       inv[i] = s * inv0;
     }
-  // for (int i=0; i<M.rows(); i++) cout << " " << long(inv[i]); cout<<endl;
+  // for (typename decltype(M)::size_type i=0; i<M.rows(); i++) cout << " " << long(inv[i]); cout<<endl;
 
-  for (int i=1; i<=M.rows(); i++)
-    for (int j=1; j<=M.cols(); j++)
+  for (typename Mat::size_type i=1; i<=M.rows(); i++)
+    for (typename Mat::size_type j=1; j<=M.cols(); j++)
       if (i > j)
         I(i,j) = M(i,j) = 0;
       else
@@ -71,8 +71,8 @@ InitMat(Mat& M, double ini[], Mat& I, double inv[], double& cond, double& maxe)
 
   maxe = 0;   // max. element
   double a = 0, b = 0, e;
-  for (int i=1; i<=M.rows(); i++)
-    for (int j=1; j<=M.cols(); j++)
+  for (typename Mat::size_type i=1; i<=M.rows(); i++)
+    for (typename Mat::size_type j=1; j<=M.cols(); j++)
       {
         e = std::abs(M(i,j));
         if (e > maxe) maxe = e;
@@ -88,12 +88,13 @@ template<class Float> void InverseTest()
   using namespace GNU_gama;
   using namespace std;
 
-  const  int   MaxN = 50;
+  using size_type = typename Mat<Float>::size_type;
+  const size_type MaxN = 50;
   double inibmat[MaxN] = {1, 2, 3};
   double inverse[MaxN];
   cout.setf(ios::scientific, ios::floatfield);
   cout.precision(3);
-  for (int N=3; N<=MaxN; N++)
+  for (size_type N=3; N<=MaxN; N++)
     {
       cout << setw(2) << sizeof(Float) << " " << setw(2) << N;
       Mat<Float> M(N,N);
@@ -103,8 +104,8 @@ template<class Float> void InverseTest()
       cout << "  cond. <= " << cond;
       Mat<Float> invM = inv(M);
       double maxdif = 0;
-      for (int i=1; i<=N; i++)
-        for (int j=1; j<=N; j++)
+      for (size_type i=1; i<=N; i++)
+        for (size_type j=1; j<=N; j++)
           if (std::abs(invM(i,j) - I(i,j)) > std::abs(maxdif))
               maxdif = invM(i,j) - I(i,j);
       cout << "  max. relative error = "
